delegates Package — Camelot documentation

### Navigation

- index
- modules |
- Camelot documentation »

# delegates Package

## `delegates` Package

Camelot includes a number of Qt delegates, most of them are used as default delegates for the various sqlalchemy and camelot field types.

Some delegates take specific arguments into account for their construction. All `field_attributes` specified for a certain field will be propagated towards the constructor of the delegate. Some of them will be used by the delegate itself, others will be used by the editor, created by the delegate.

### BoolDelegate

Custom delegate for boolean values

By default, creates a BoolEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - minimum
> - maximum
> - nullable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### ChartDelegate

Custom delegate for Matplotlib charts

### CodeDelegate

Field attributes supported by the delegate :

> - parts
> - separator

By default, creates a CodeEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - parts
> - editable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### ColorDelegate

By default, creates a ColorEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - editable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### ColoredFloatDelegate

Custom delegate for float values.

> The class attribute icons is used to customize the icons displayed.

Field attributes supported by the delegate :

> - minimum
> - maximum
> - precision
> - reverse
> - neutral
> - unicode_format

By default, creates a ColoredFloatEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - precision
> - reverse
> - neutral
> - option
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip
> - prefix
> - suffix
> - minimum
> - maximum
> - single_step

### ComboBoxDelegate

By default, creates a ChoicesEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - nullable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - choices

### CurrencyDelegate

Custom delegate for currency values

### DateDelegate

Custom delegate for date values

Field attributes supported by the delegate :

By default, creates a DateEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - editable
> - nullable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### DateTimeDelegate

Field attributes supported by the delegate :

> - editable

By default, creates a DateTimeEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - editable
> - nullable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### EnumerationDelegate

Contrary to the comboboxdelegate, the enumeration delegate does not support dynamic
  choices

Field attributes supported by the delegate :

> - choices
> - editable

By default, creates a ChoicesEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - nullable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - choices

### FileDelegate

Delegate for camelot.types.file fields. Expects values of type camelot.core.files.storage.StoredFile.

By default, creates a FileEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - storage
> - field_name
> - remove_original

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip
> - remove_original

### FloatDelegate

Custom delegate for float values

Field attributes supported by the delegate :

> - minimum
> - maximum
> - unicode_format

By default, creates a FloatEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - minimum
> - maximum
> - calculator
> - decimal
> - option
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip
> - prefix
> - suffix
> - precision
> - single_step

### ImageDelegate

### IntegerDelegate

Custom delegate for integer values

Field attributes supported by the delegate :

> - minimum
> - maximum
> - unicode_format

By default, creates a IntegerEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - minimum
> - maximum
> - calculator
> - option
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip
> - prefix
> - suffix
> - nullable
> - single_step

### IntervalsDelegate

Custom delegate for visualizing camelot.container.IntervalsContainer
  data:

### LabelDelegate

Delegate to display an attribute as a label

By default, creates a LabelEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - text
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### LanguageDelegate

### LocalFileDelegate

Delegate for displaying a path on the local file system. This path can
  either point to a file or a directory

Field attributes supported by the delegate :

By default, creates a LocalFileEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - field_name
> - directory
> - save_as
> - file_filter

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### Many2OneDelegate

Custom delegate for many 2 one relations

> Once an item has been selected, it is represented by its unicode representation in the editor or the table. So the related classes need an implementation of their __unicode__ method.

Field attributes supported by the delegate :

> - admin
> - embedded
> - editable

By default, creates a Many2OneEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - admin
> - editable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### ManyToManyDelegate

### ManyToOneChoicesDelegate

Display a ManyToOne field as a ComboBox, filling the list of choices with

  the objects of the target class.

  The items in the ComboBox are the unicode representation of the related objects. So these classes need an implementation of their __unicode__ method to show up in a human readable way in the ComboBox.

### MonthsDelegate

MonthsDelegate

> custom delegate for showing and editing months and years

Field attributes supported by the delegate :

> - forever

By default, creates a MonthsEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - editable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### NoteDelegate

By default, creates a NoteEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### One2ManyDelegate

Custom delegate for many 2 one relations

Field attributes supported by the delegate :

### PlainTextDelegate

Custom delegate for simple string values

Field attributes supported by the delegate :

> - length
> - editable
> - translate_content

By default, creates a TextLineEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - length
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### RichTextDelegate

Custom delegate for rich text (HTML) string values

Field attributes supported by the delegate :

> - editable

By default, creates a RichTextEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color

### SmileyDelegate

Delegate for Smiley’s

Field attributes supported by the delegate :

> - editable
> - icons

By default, creates a SmileyEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - editable
> - icons
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### StarDelegate

Delegate for integer values from (1 to 5)(Rating Delegate)

Field attributes supported by the delegate :

> - editable
> - maximum

By default, creates a StarEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - maximum
> - editable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### TextBoolDelegate

### TextEditDelegate

Custom delegate for simple string values

Field attributes supported by the delegate :

By default, creates a TextEditEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - length
> - editable
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### TimeDelegate

Field attributes supported by the delegate :

> - editable

By default, creates a TimeEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - editable
> - field_name
> - format

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

### VirtualAddressDelegate

Field attributes supported by the delegate :

> - editable
> - address_type

By default, creates a VirtualAddressEditor as its editor.

Field Attributes | Editor
editable=False tooltip=’tooltip’ |
editable=True |
editable=True tooltip=’tooltip’ |
editable=False |
editable=False background_color=ColorScheme.green |
editable=True background_color=ColorScheme.green |

Static attributes supported by this editor :

> - editable
> - address_type
> - address_validator
> - field_name

Dynamic field attributes supported by the editor :

> - editable
> - background_color
> - tooltip

class `camelot.view.controls.delegates.` `DelegateManager`(parent=None, **kwargs)

  Bases: `PyQt4.QtGui.QItemDelegate`

  Manages custom delegates, should not be used by the application developer

  `createEditor`(parent, option, index)

    Use a custom delegate createEditor method if it exists

  `get_column_delegate`(column)
  `insertColumnDelegate`(column, delegate)

    Inserts a custom column delegate

  `paint`(painter, option, index)

    Use a custom delegate paint method if it exists

  `removeColumnDelegate`(column)

    Removes custom column delegate

  `setEditorData`(editor, index)

    Use a custom delegate setEditorData method if it exists

  `setModelData`(editor, model, index)

    Use a custom delegate setModelData method if it exists

  `set_columns_desc`(columnsdesc)
  `sizeHint`(option, index)

class `camelot.view.controls.delegates.` `BoolDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for boolean values

  By default, creates a BoolEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - minimum
  > - maximum
  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `BoolEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `TextBoolDelegate`(parent=None, editable=True, yes='Yes', no='No', color_yes=None, color_no=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  `editor`

    alias of `TextBoolEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `ChartDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for Matplotlib charts

  `editor`

    alias of `ChartEditor`

  `setModelData`(editor, model, index)

class `camelot.view.controls.delegates.` `CodeDelegate`(parent=None, parts=[], separator=u'.', **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Field attributes supported by the delegate :

  > - parts
  > - separator

  By default, creates a CodeEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - parts
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `CodeEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `ColorDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  By default, creates a ColorEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `ColorEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `ColoredFloatDelegate`(parent=None, minimum=-1000000000000000.0, maximum=1000000000000000.0, precision=2, reverse=False, neutral=False, unicode_format=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for float values.

  > The class attribute icons is used to customize the icons displayed.

  Field attributes supported by the delegate :

  > - minimum
  > - maximum
  > - precision
  > - reverse
  > - neutral
  > - unicode_format

  By default, creates a ColoredFloatEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - precision
  > - reverse
  > - neutral
  > - option
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - prefix
  > - suffix
  > - minimum
  > - maximum
  > - single_step

  `editor`

    alias of `ColoredFloatEditor`

  `icons` = {0: 'tango/16x16/actions/zero.png', 1: 'tango/16x16/actions/go-up.png', -1: 'tango/16x16/actions/go-down-red.png'}
  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `ComboBoxDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  By default, creates a ChoicesEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - choices

  `editor`

    alias of `ChoicesEditor`

  `paint`(painter, option, index)
  `setEditorData`(editor, index)

class `camelot.view.controls.delegates.` `CurrencyDelegate`(minimum=-1000000000000000.0, maximum=1000000000000000.0, parent=None, unicode_format=None, **kwargs)

  Bases: `camelot.view.controls.delegates.floatdelegate.FloatDelegate`

  Custom delegate for currency values

class `camelot.view.controls.delegates.` `CustomDelegate`(parent=None, editable=True, **kwargs)

  Bases: `PyQt4.QtGui.QItemDelegate`

  Base class for implementing custom delegates.

  `editor`

  class attribute specifies the editor class that should be used

  `commitAndCloseEditor`()
  `createEditor`(parent, option, index)

    Parameters: | option – use an option with version 5 to indicate the widget

    will be put onto a form

  `editor` = None
  `paint`(painter, option, index)
  `paint_text`(painter, option, index, text, margin_left=0, margin_right=0, horizontal_align=1, vertical_align=128)

    Paint unicode text into the given rect defined by option, and fill the rect with the background color :arg margin_left: additional margin to the left, to be used for icons or others :arg margin_right: additional margin to the right, to be used for icons or others

  `render_html`(index)

    Generator that renders a value to html

  `render_ooxml`(value)

    Generator for label text in Office Open XML representing this form

  `setEditorData`(editor, index)
  `setModelData`(editor, model, index)
  `sizeHint`(option, index)

class `camelot.view.controls.delegates.` `DateDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for date values

  Field attributes supported by the delegate :

  By default, creates a DateEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `DateEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `DateTimeDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Field attributes supported by the delegate :

  > - editable

  By default, creates a DateTimeEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `DateTimeEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `EnumerationDelegate`(parent=None, choices=[], editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Contrary to the comboboxdelegate, the enumeration delegate does not support dynamic
    choices

  Field attributes supported by the delegate :

  > - choices
  > - editable

  By default, creates a ChoicesEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - choices

  `createEditor`(parent, option, index)
  `editor`

    alias of `ChoicesEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `FileDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate for camelot.types.file fields. Expects values of type camelot.core.files.storage.StoredFile.

  By default, creates a FileEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - storage
  > - field_name
  > - remove_original

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - remove_original

  `editor`

    alias of `FileEditor`

  `paint`(painter, option, index, background_color=<PyQt4.QtGui.QColor object at 0xa134f0c>)

class `camelot.view.controls.delegates.` `FloatDelegate`(minimum=-1000000000000000.0, maximum=1000000000000000.0, parent=None, unicode_format=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for float values

  Field attributes supported by the delegate :

  > - minimum
  > - maximum
  > - unicode_format

  By default, creates a FloatEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - minimum
  > - maximum
  > - calculator
  > - decimal
  > - option
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - prefix
  > - suffix
  > - precision
  > - single_step

  `editor`

    alias of `FloatEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `ImageDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.filedelegate.FileDelegate`

  `editor`

    alias of `ImageEditor`

  `margin` = 2
  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `IntegerDelegate`(minimum=-2147483648, maximum=2147483647, parent=None, unicode_format=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for integer values

  Field attributes supported by the delegate :

  > - minimum
  > - maximum
  > - unicode_format

  By default, creates a IntegerEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - minimum
  > - maximum
  > - calculator
  > - option
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - prefix
  > - suffix
  > - nullable
  > - single_step

  `editor`

    alias of `IntegerEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `IntervalsDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for visualizing camelot.container.IntervalsContainer
    data:
  `createEditor`(parent, option, index)
  `paint`(painter, option, index)
  `setEditorData`(editor, index)
  `setModelData`(editor, model, index)

class `camelot.view.controls.delegates.` `LanguageDelegate`(parent=None, length=20, editable=True, translate_content=False, **kw)

  Bases: `camelot.view.controls.delegates.plaintextdelegate.PlainTextDelegate`

  `editor`

    alias of `LanguageEditor`

class `camelot.view.controls.delegates.` `LocalFileDelegate`(parent=None, **kw)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate for displaying a path on the local file system. This path can
    either point to a file or a directory

  Field attributes supported by the delegate :

  By default, creates a LocalFileEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - field_name
  > - directory
  > - save_as
  > - file_filter

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `LocalFileEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `ManyToManyDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.one2manydelegate.One2ManyDelegate`

  `commitAndCloseEditor`()
  `createEditor`(parent, option, index)
  `setModelData`(editor, model, index)

class `camelot.view.controls.delegates.` `Many2OneDelegate`(parent=None, admin=None, embedded=False, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for many 2 one relations

  > Once an item has been selected, it is represented by its unicode representation in the editor or the table. So the related classes need an implementation of their __unicode__ method.

  Field attributes supported by the delegate :

  > - admin
  > - embedded
  > - editable

  By default, creates a Many2OneEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - admin
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `createEditor`(parent, option, index)
  `editor`

    alias of `Many2OneEditor`

  `paint`(painter, option, index)
  `setEditorData`(editor, index)
  `setModelData`(editor, model, index)

class `camelot.view.controls.delegates.` `One2ManyDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for many 2 one relations

  Field attributes supported by the delegate :

  `createEditor`(parent, option, index)
  `render_ooxml`(value)
  `setEditorData`(editor, index)
  `setModelData`(editor, model, index)

class `camelot.view.controls.delegates.` `ManyToOneChoicesDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Display a ManyToOne field as a ComboBox, filling the list of choices with the objects of the target class.

  The items in the ComboBox are the unicode representation of the related objects. So these classes need an implementation of their __unicode__ method to show up in a human readable way in the ComboBox.

  `editor`

    alias of `OneToManyChoicesEditor`

class `camelot.view.controls.delegates.` `PlainTextDelegate`(parent=None, length=20, editable=True, translate_content=False, **kw)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for simple string values

  Field attributes supported by the delegate :

  > - length
  > - editable
  > - translate_content

  By default, creates a TextLineEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - length
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `TextLineEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `RichTextDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for rich text (HTML) string values

  Field attributes supported by the delegate :

  > - editable

  By default, creates a RichTextEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color

  `editor`

    alias of `RichTextEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `StarDelegate`(parent=None, editable=True, maximum=5, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate for integer values from (1 to 5)(Rating Delegate)

  Field attributes supported by the delegate :

  > - editable
  > - maximum

  By default, creates a StarEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - maximum
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `StarEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `TextEditDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for simple string values

  Field attributes supported by the delegate :

  By default, creates a TextEditEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - length
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `TextEditEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `TimeDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Field attributes supported by the delegate :

  > - editable

  By default, creates a TimeEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - field_name
  > - format

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `TimeEditor`

  `paint`(painter, option, index)
  `setModelData`(editor, model, index)

class `camelot.view.controls.delegates.` `VirtualAddressDelegate`(parent=None, editable=True, address_type=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Field attributes supported by the delegate :

  > - editable
  > - address_type

  By default, creates a VirtualAddressEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - address_type
  > - address_validator
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `VirtualAddressEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `SmileyDelegate`(parent, editable=True, icons=[('face-angel', Icon('tango/16x16/emotes/face-angel.png')), ('face-crying', Icon('tango/16x16/emotes/face-crying.png')), ('face-devilish', Icon('tango/16x16/emotes/face-devilish.png')), ('face-glasses', Icon('tango/16x16/emotes/face-glasses.png')), ('face-grin', Icon('tango/16x16/emotes/face-grin.png')), ('face-kiss', Icon('tango/16x16/emotes/face-kiss.png')), ('face-monkey', Icon('tango/16x16/emotes/face-monkey.png')), ('face-plain', Icon('tango/16x16/emotes/face-plain.png')), ('face-sad', Icon('tango/16x16/emotes/face-sad.png')), ('face-smile', Icon('tango/16x16/emotes/face-smile.png')), ('face-smile-big', Icon('tango/16x16/emotes/face-smile-big.png')), ('face-surprise', Icon('tango/16x16/emotes/face-surprise.png')), ('face-wink', Icon('tango/16x16/emotes/face-wink.png'))], **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate for Smiley’s

  Field attributes supported by the delegate :

  > - editable
  > - icons

  By default, creates a SmileyEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - icons
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `SmileyEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.` `NoteDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.texteditdelegate.TextEditDelegate`

  By default, creates a NoteEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `NoteEditor`

class `camelot.view.controls.delegates.` `LabelDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate to display an attribute as a label

  By default, creates a LabelEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - text
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `LabelEditor`

class `camelot.view.controls.delegates.` `MonthsDelegate`(parent=None, forever=2400, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  MonthsDelegate

  > custom delegate for showing and editing months and years

  Field attributes supported by the delegate :

  > - forever

  By default, creates a MonthsEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `MonthsEditor`

  `paint`(painter, option, index)
  `sizeHint`(option, index)

## `booldelegate` Module

class `camelot.view.controls.delegates.booldelegate.` `BoolDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for boolean values

  By default, creates a BoolEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - minimum
  > - maximum
  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `BoolEditor`

  `paint`(painter, option, index)

class `camelot.view.controls.delegates.booldelegate.` `TextBoolDelegate`(parent=None, editable=True, yes='Yes', no='No', color_yes=None, color_no=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  `editor`

    alias of `TextBoolEditor`

  `paint`(painter, option, index)

## `chartdelegate` Module

class `camelot.view.controls.delegates.chartdelegate.` `ChartDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for Matplotlib charts

  `editor`

    alias of `ChartEditor`

  `setModelData`(editor, model, index)

## `codedelegate` Module

class `camelot.view.controls.delegates.codedelegate.` `CodeDelegate`(parent=None, parts=[], separator=u'.', **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Field attributes supported by the delegate :

  > - parts
  > - separator

  By default, creates a CodeEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - parts
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `CodeEditor`

  `paint`(painter, option, index)

## `colordelegate` Module

class `camelot.view.controls.delegates.colordelegate.` `ColorDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  By default, creates a ColorEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `ColorEditor`

  `paint`(painter, option, index)

## `coloredfloatdelegate` Module

class `camelot.view.controls.delegates.coloredfloatdelegate.` `ColoredFloatDelegate`(parent=None, minimum=-1000000000000000.0, maximum=1000000000000000.0, precision=2, reverse=False, neutral=False, unicode_format=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for float values.

  > The class attribute icons is used to customize the icons displayed.

  Field attributes supported by the delegate :

  > - minimum
  > - maximum
  > - precision
  > - reverse
  > - neutral
  > - unicode_format

  By default, creates a ColoredFloatEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - precision
  > - reverse
  > - neutral
  > - option
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - prefix
  > - suffix
  > - minimum
  > - maximum
  > - single_step

  `editor`

    alias of `ColoredFloatEditor`

  `icons` = {0: 'tango/16x16/actions/zero.png', 1: 'tango/16x16/actions/go-up.png', -1: 'tango/16x16/actions/go-down-red.png'}
  `paint`(painter, option, index)

## `comboboxdelegate` Module

class `camelot.view.controls.delegates.comboboxdelegate.` `ComboBoxDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  By default, creates a ChoicesEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - choices

  `editor`

    alias of `ChoicesEditor`

  `paint`(painter, option, index)
  `setEditorData`(editor, index)

## `currencydelegate` Module

class `camelot.view.controls.delegates.currencydelegate.` `CurrencyDelegate`(minimum=-1000000000000000.0, maximum=1000000000000000.0, parent=None, unicode_format=None, **kwargs)

  Bases: `camelot.view.controls.delegates.floatdelegate.FloatDelegate`

  Custom delegate for currency values

## `customdelegate` Module

class `camelot.view.controls.delegates.customdelegate.` `CustomDelegate`(parent=None, editable=True, **kwargs)

  Bases: `PyQt4.QtGui.QItemDelegate`

  Base class for implementing custom delegates.

  `editor`

  class attribute specifies the editor class that should be used

  `commitAndCloseEditor`()
  `createEditor`(parent, option, index)

    Parameters: | option – use an option with version 5 to indicate the widget

    will be put onto a form

  `editor` = None
  `paint`(painter, option, index)
  `paint_text`(painter, option, index, text, margin_left=0, margin_right=0, horizontal_align=1, vertical_align=128)

    Paint unicode text into the given rect defined by option, and fill the rect with the background color :arg margin_left: additional margin to the left, to be used for icons or others :arg margin_right: additional margin to the right, to be used for icons or others

  `render_html`(index)

    Generator that renders a value to html

  `render_ooxml`(value)

    Generator for label text in Office Open XML representing this form

  `setEditorData`(editor, index)
  `setModelData`(editor, model, index)
  `sizeHint`(option, index)

`camelot.view.controls.delegates.customdelegate.` `DocumentationMetaclass`(name, bases, dct)

## `datedelegate` Module

class `camelot.view.controls.delegates.datedelegate.` `DateDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for date values

  Field attributes supported by the delegate :

  By default, creates a DateEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `DateEditor`

  `paint`(painter, option, index)

## `datetimedelegate` Module

class `camelot.view.controls.delegates.datetimedelegate.` `DateTimeDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Field attributes supported by the delegate :

  > - editable

  By default, creates a DateTimeEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `DateTimeEditor`

  `paint`(painter, option, index)

## `delegatemanager` Module

class `camelot.view.controls.delegates.delegatemanager.` `DelegateManager`(parent=None, **kwargs)

  Bases: `PyQt4.QtGui.QItemDelegate`

  Manages custom delegates, should not be used by the application developer

  `createEditor`(parent, option, index)

    Use a custom delegate createEditor method if it exists

  `get_column_delegate`(column)
  `insertColumnDelegate`(column, delegate)

    Inserts a custom column delegate

  `paint`(painter, option, index)

    Use a custom delegate paint method if it exists

  `removeColumnDelegate`(column)

    Removes custom column delegate

  `setEditorData`(editor, index)

    Use a custom delegate setEditorData method if it exists

  `setModelData`(editor, model, index)

    Use a custom delegate setModelData method if it exists

  `set_columns_desc`(columnsdesc)
  `sizeHint`(option, index)

## `enumerationdelegate` Module

class `camelot.view.controls.delegates.enumerationdelegate.` `EnumerationDelegate`(parent=None, choices=[], editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Contrary to the comboboxdelegate, the enumeration delegate does not support dynamic
    choices

  Field attributes supported by the delegate :

  > - choices
  > - editable

  By default, creates a ChoicesEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - nullable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - choices

  `createEditor`(parent, option, index)
  `editor`

    alias of `ChoicesEditor`

  `paint`(painter, option, index)

## `filedelegate` Module

class `camelot.view.controls.delegates.filedelegate.` `FileDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate for camelot.types.file fields. Expects values of type camelot.core.files.storage.StoredFile.

  By default, creates a FileEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - storage
  > - field_name
  > - remove_original

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - remove_original

  `editor`

    alias of `FileEditor`

  `paint`(painter, option, index, background_color=<PyQt4.QtGui.QColor object at 0xa134f0c>)

## `floatdelegate` Module

class `camelot.view.controls.delegates.floatdelegate.` `FloatDelegate`(minimum=-1000000000000000.0, maximum=1000000000000000.0, parent=None, unicode_format=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for float values

  Field attributes supported by the delegate :

  > - minimum
  > - maximum
  > - unicode_format

  By default, creates a FloatEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - minimum
  > - maximum
  > - calculator
  > - decimal
  > - option
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - prefix
  > - suffix
  > - precision
  > - single_step

  `editor`

    alias of `FloatEditor`

  `paint`(painter, option, index)

## `imagedelegate` Module

class `camelot.view.controls.delegates.imagedelegate.` `ImageDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.filedelegate.FileDelegate`

  `editor`

    alias of `ImageEditor`

  `margin` = 2
  `paint`(painter, option, index)

## `integerdelegate` Module

class `camelot.view.controls.delegates.integerdelegate.` `IntegerDelegate`(minimum=-2147483648, maximum=2147483647, parent=None, unicode_format=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for integer values

  Field attributes supported by the delegate :

  > - minimum
  > - maximum
  > - unicode_format

  By default, creates a IntegerEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - minimum
  > - maximum
  > - calculator
  > - option
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip
  > - prefix
  > - suffix
  > - nullable
  > - single_step

  `editor`

    alias of `IntegerEditor`

  `paint`(painter, option, index)

## `intervalsdelegate` Module

class `camelot.view.controls.delegates.intervalsdelegate.` `IntervalsDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for visualizing camelot.container.IntervalsContainer
    data:
  `createEditor`(parent, option, index)
  `paint`(painter, option, index)
  `setEditorData`(editor, index)
  `setModelData`(editor, model, index)

## `labeldelegate` Module

class `camelot.view.controls.delegates.labeldelegate.` `LabelDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate to display an attribute as a label

  By default, creates a LabelEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - text
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `LabelEditor`

## `languagedelegate` Module

class `camelot.view.controls.delegates.languagedelegate.` `LanguageDelegate`(parent=None, length=20, editable=True, translate_content=False, **kw)

  Bases: `camelot.view.controls.delegates.plaintextdelegate.PlainTextDelegate`

  `editor`

    alias of `LanguageEditor`

## `localfiledelegate` Module

class `camelot.view.controls.delegates.localfiledelegate.` `LocalFileDelegate`(parent=None, **kw)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate for displaying a path on the local file system. This path can
    either point to a file or a directory

  Field attributes supported by the delegate :

  By default, creates a LocalFileEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - field_name
  > - directory
  > - save_as
  > - file_filter

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `LocalFileEditor`

  `paint`(painter, option, index)

## `many2onedelegate` Module

class `camelot.view.controls.delegates.many2onedelegate.` `Many2OneDelegate`(parent=None, admin=None, embedded=False, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for many 2 one relations

  > Once an item has been selected, it is represented by its unicode representation in the editor or the table. So the related classes need an implementation of their __unicode__ method.

  Field attributes supported by the delegate :

  > - admin
  > - embedded
  > - editable

  By default, creates a Many2OneEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - admin
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `createEditor`(parent, option, index)
  `editor`

    alias of `Many2OneEditor`

  `paint`(painter, option, index)
  `setEditorData`(editor, index)
  `setModelData`(editor, model, index)

## `manytomanydelegate` Module

class `camelot.view.controls.delegates.manytomanydelegate.` `ManyToManyDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.one2manydelegate.One2ManyDelegate`

  `commitAndCloseEditor`()
  `createEditor`(parent, option, index)
  `setModelData`(editor, model, index)

## `manytoonechoicesdelegate` Module

class `camelot.view.controls.delegates.manytoonechoicesdelegate.` `ManyToOneChoicesDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Display a ManyToOne field as a ComboBox, filling the list of choices with the objects of the target class.

  The items in the ComboBox are the unicode representation of the related objects. So these classes need an implementation of their __unicode__ method to show up in a human readable way in the ComboBox.

  `editor`

    alias of `OneToManyChoicesEditor`

## `monthsdelegate` Module

class `camelot.view.controls.delegates.monthsdelegate.` `MonthsDelegate`(parent=None, forever=2400, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  MonthsDelegate

  > custom delegate for showing and editing months and years

  Field attributes supported by the delegate :

  > - forever

  By default, creates a MonthsEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `MonthsEditor`

  `paint`(painter, option, index)
  `sizeHint`(option, index)

## `notedelegate` Module

class `camelot.view.controls.delegates.notedelegate.` `NoteDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.texteditdelegate.TextEditDelegate`

  By default, creates a NoteEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `NoteEditor`

## `one2manydelegate` Module

class `camelot.view.controls.delegates.one2manydelegate.` `One2ManyDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for many 2 one relations

  Field attributes supported by the delegate :

  `createEditor`(parent, option, index)
  `render_ooxml`(value)
  `setEditorData`(editor, index)
  `setModelData`(editor, model, index)

## `plaintextdelegate` Module

class `camelot.view.controls.delegates.plaintextdelegate.` `PlainTextDelegate`(parent=None, length=20, editable=True, translate_content=False, **kw)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for simple string values

  Field attributes supported by the delegate :

  > - length
  > - editable
  > - translate_content

  By default, creates a TextLineEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - length
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `TextLineEditor`

  `paint`(painter, option, index)

## `richtextdelegate` Module

class `camelot.view.controls.delegates.richtextdelegate.` `RichTextDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for rich text (HTML) string values

  Field attributes supported by the delegate :

  > - editable

  By default, creates a RichTextEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color

  `editor`

    alias of `RichTextEditor`

  `paint`(painter, option, index)

## `smileydelegate` Module

class `camelot.view.controls.delegates.smileydelegate.` `SmileyDelegate`(parent, editable=True, icons=[('face-angel', Icon('tango/16x16/emotes/face-angel.png')), ('face-crying', Icon('tango/16x16/emotes/face-crying.png')), ('face-devilish', Icon('tango/16x16/emotes/face-devilish.png')), ('face-glasses', Icon('tango/16x16/emotes/face-glasses.png')), ('face-grin', Icon('tango/16x16/emotes/face-grin.png')), ('face-kiss', Icon('tango/16x16/emotes/face-kiss.png')), ('face-monkey', Icon('tango/16x16/emotes/face-monkey.png')), ('face-plain', Icon('tango/16x16/emotes/face-plain.png')), ('face-sad', Icon('tango/16x16/emotes/face-sad.png')), ('face-smile', Icon('tango/16x16/emotes/face-smile.png')), ('face-smile-big', Icon('tango/16x16/emotes/face-smile-big.png')), ('face-surprise', Icon('tango/16x16/emotes/face-surprise.png')), ('face-wink', Icon('tango/16x16/emotes/face-wink.png'))], **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate for Smiley’s

  Field attributes supported by the delegate :

  > - editable
  > - icons

  By default, creates a SmileyEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - icons
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `SmileyEditor`

  `paint`(painter, option, index)

## `stardelegate` Module

class `camelot.view.controls.delegates.stardelegate.` `StarDelegate`(parent=None, editable=True, maximum=5, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Delegate for integer values from (1 to 5)(Rating Delegate)

  Field attributes supported by the delegate :

  > - editable
  > - maximum

  By default, creates a StarEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - maximum
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `StarEditor`

  `paint`(painter, option, index)

## `texteditdelegate` Module

class `camelot.view.controls.delegates.texteditdelegate.` `TextEditDelegate`(parent=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Custom delegate for simple string values

  Field attributes supported by the delegate :

  By default, creates a TextEditEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - length
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `TextEditEditor`

  `paint`(painter, option, index)

## `timedelegate` Module

class `camelot.view.controls.delegates.timedelegate.` `TimeDelegate`(parent=None, editable=True, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Field attributes supported by the delegate :

  > - editable

  By default, creates a TimeEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - field_name
  > - format

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `TimeEditor`

  `paint`(painter, option, index)
  `setModelData`(editor, model, index)

## `virtualaddressdelegate` Module

class `camelot.view.controls.delegates.virtualaddressdelegate.` `VirtualAddressDelegate`(parent=None, editable=True, address_type=None, **kwargs)

  Bases: `camelot.view.controls.delegates.customdelegate.CustomDelegate`

  Field attributes supported by the delegate :

  > - editable
  > - address_type

  By default, creates a VirtualAddressEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - address_type
  > - address_validator
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `VirtualAddressEditor`

  `paint`(painter, option, index)

### Navigation

- index
- modules |
- Camelot documentation »

Comments
blog comments powered by Disqus